@@ -1,4 +1,17 @@
-# Copyright (c) 2019 NVIDIA Corporation
+# Copyright (c) 2020, NVIDIA CORPORATION.  All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import collections
 import json
 import os
@@ -6,10 +19,8 @@ from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
 
-import nemo
 from nemo.collections.asr.parts import manifest, parsers
-
-logging = nemo.logging
+from nemo.utils import logging
 
 
 class _Collection(collections.UserList):
@@ -80,38 +91,51 @@ class AudioText(_Collection):
     """List of audio-transcript text correspondence with preprocessing."""
 
     OUTPUT_TYPE = collections.namedtuple(
-        typename='AudioTextEntity', field_names='audio_file duration text_tokens offset',
+        typename='AudioTextEntity', field_names='id audio_file duration text_tokens offset text_raw speaker orig_sr',
     )
 
     def __init__(
         self,
+        ids: List[int],
         audio_files: List[str],
         durations: List[float],
         texts: List[str],
         offsets: List[str],
+        speakers: List[Optional[int]],
+        orig_sampling_rates: List[Optional[int]],
         parser: parsers.CharParser,
         min_duration: Optional[float] = None,
         max_duration: Optional[float] = None,
         max_number: Optional[int] = None,
         do_sort_by_duration: bool = False,
+        index_by_file_id: bool = False,
     ):
         """Instantiates audio-text manifest with filters and preprocessing.
 
         Args:
+            ids: List of examples positions.
             audio_files: List of audio files.
             durations: List of float durations.
             texts: List of raw text transcripts.
             offsets: List of duration offsets or None.
+            speakers: List of optional speakers ids.
+            orig_sampling_rates: List of original sampling rates of audio files.
             parser: Instance of `CharParser` to convert string to tokens.
             min_duration: Minimum duration to keep entry with (default: None).
             max_duration: Maximum duration to keep entry with (default: None).
             max_number: Maximum number of samples to collect.
-            do_sort_by_duration: True if sort samples list by duration.
+            do_sort_by_duration: True if sort samples list by duration. Not compatible with index_by_file_id.
+            index_by_file_id: If True, saves a mapping from filename base (ID) to index in data.
         """
 
         output_type = self.OUTPUT_TYPE
         data, duration_filtered, num_filtered, total_duration = [], 0.0, 0, 0.0
-        for audio_file, duration, text, offset in zip(audio_files, durations, texts, offsets):
+        if index_by_file_id:
+            self.mapping = {}
+
+        for id_, audio_file, duration, offset, text, speaker, orig_sr in zip(
+            ids, audio_files, durations, offsets, texts, speakers, orig_sampling_rates
+        ):
             # Duration filters.
             if min_duration is not None and duration < min_duration:
                 duration_filtered += duration
@@ -130,14 +154,21 @@ class AudioText(_Collection):
                 continue
 
             total_duration += duration
-            data.append(output_type(audio_file, duration, text_tokens, offset))
+
+            data.append(output_type(id_, audio_file, duration, text_tokens, offset, text, speaker, orig_sr))
+            if index_by_file_id:
+                file_id, _ = os.path.splitext(os.path.basename(audio_file))
+                self.mapping[file_id] = len(data) - 1
 
             # Max number of entities filter.
             if len(data) == max_number:
                 break
 
         if do_sort_by_duration:
-            data.sort(key=lambda entity: entity.duration)
+            if index_by_file_id:
+                logging.warning("Tried to sort dataset by duration, but cannot since index_by_file_id is set.")
+            else:
+                data.sort(key=lambda entity: entity.duration)
 
         logging.info("Dataset loaded with %d files totalling %.2f hours", len(data), total_duration / 3600)
         logging.info("%d files were filtered totalling %.2f hours", num_filtered, duration_filtered / 3600)
@@ -158,14 +189,17 @@ class ASRAudioText(AudioText):
             **kwargs: Kwargs to pass to `AudioText` constructor.
         """
 
-        audio_files, durations, texts, offsets = [], [], [], []
+        ids, audio_files, durations, texts, offsets, speakers, orig_srs = [], [], [], [], [], [], []
         for item in manifest.item_iter(manifests_files):
+            ids.append(item['id'])
             audio_files.append(item['audio_file'])
             durations.append(item['duration'])
             texts.append(item['text'])
             offsets.append(item['offset'])
+            speakers.append(item['speaker'])
+            orig_srs.append(item['orig_sr'])
 
-        super().__init__(audio_files, durations, texts, offsets, *args, **kwargs)
+        super().__init__(ids, audio_files, durations, texts, offsets, speakers, orig_srs, *args, **kwargs)
 
 
 class SpeechLabel(_Collection):
@@ -183,6 +217,7 @@ class SpeechLabel(_Collection):
         max_duration: Optional[float] = None,
         max_number: Optional[int] = None,
         do_sort_by_duration: bool = False,
+        index_by_file_id: bool = False,
     ):
         """Instantiates audio-label manifest with filters and preprocessing.
 
@@ -195,8 +230,11 @@ class SpeechLabel(_Collection):
             max_duration: Maximum duration to keep entry with (default: None).
             max_number: Maximum number of samples to collect.
             do_sort_by_duration: True if sort samples list by duration.
+            index_by_file_id: If True, saves a mapping from filename base (ID) to index in data.
         """
 
+        if index_by_file_id:
+            self.mapping = {}
         output_type = self.OUTPUT_TYPE
         data, duration_filtered = [], 0.0
         for audio_file, duration, command, offset in zip(audio_files, durations, labels, offsets):
@@ -211,16 +249,25 @@ class SpeechLabel(_Collection):
 
             data.append(output_type(audio_file, duration, command, offset))
 
+            if index_by_file_id:
+                file_id, _ = os.path.splitext(os.path.basename(audio_file))
+                self.mapping[file_id] = len(data) - 1
+
             # Max number of entities filter.
             if len(data) == max_number:
                 break
 
         if do_sort_by_duration:
-            data.sort(key=lambda entity: entity.duration)
+            if index_by_file_id:
+                logging.warning("Tried to sort dataset by duration, but cannot since index_by_file_id is set.")
+            else:
+                data.sort(key=lambda entity: entity.duration)
 
         logging.info(
             "Filtered duration for loading collection is %f.", duration_filtered,
         )
+        self.uniq_labels = sorted(set(map(lambda x: x.label, data)))
+        logging.info("# {} files loaded accounting to # {} labels".format(len(data), len(self.uniq_labels)))
 
         super().__init__(data)
 
@@ -228,12 +275,13 @@ class SpeechLabel(_Collection):
 class ASRSpeechLabel(SpeechLabel):
     """`SpeechLabel` collector from structured json files."""
 
-    def __init__(self, manifests_files: Union[str, List[str]], *args, **kwargs):
+    def __init__(self, manifests_files: Union[str, List[str]], is_regression_task=False, *args, **kwargs):
         """Parse lists of audio files, durations and transcripts texts.
 
         Args:
             manifests_files: Either single string file or list of such -
                 manifests to yield items from.
+            is_regression_task: It's a regression task
             *args: Args to pass to `SpeechLabel` constructor.
             **kwargs: Kwargs to pass to `SpeechLabel` constructor.
         """
@@ -242,7 +290,11 @@ class ASRSpeechLabel(SpeechLabel):
         for item in manifest.item_iter(manifests_files, parse_func=self.__parse_item):
             audio_files.append(item['audio_file'])
             durations.append(item['duration'])
-            labels.append(item['label'])
+            if not is_regression_task:
+                labels.append(item['label'])
+            else:
+                labels.append(float(item['label']))
+
             offsets.append(item['offset'])
 
         super().__init__(audio_files, durations, labels, offsets, *args, **kwargs)
